==> jc-1.4.0.tar.gz: scm/scmaddMethod.h <==
// class scm.scmaddMethod

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 2456fb15458328b3 scm_scmaddMethod

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmaddMethod_H_
#define _JC_scm_scmaddMethod_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmaddMethod$sub_refs	_jc_scm_scmaddMethod$sub_refs;
typedef struct _jc_scm_scmaddMethod$sub_nonrefs	_jc_scm_scmaddMethod$sub_nonrefs;
typedef struct _jc_scm_scmaddMethod$refs	_jc_scm_scmaddMethod$refs;
typedef struct _jc_scm_scmaddMethod$nonrefs	_jc_scm_scmaddMethod$nonrefs;
typedef struct _jc_scm_scmaddMethod$object	_jc_scm_scmaddMethod$object;

typedef const struct _jc_scm_scmaddMethod$vmethods	_jc_scm_scmaddMethod$vmethods;
typedef const struct _jc_scm_scmaddMethod$vtable	_jc_scm_scmaddMethod$vtable;
typedef const struct _jc_scm_scmaddMethod$vtype	_jc_scm_scmaddMethod$vtype;

// Constructors
extern void _jc_scm_scmaddMethod$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmaddMethod$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_scmaddMethod$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmaddMethod$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_scmaddMethod$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmaddMethod$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_scmaddMethod$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmaddMethod$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmaddMethod$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmaddMethod$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmaddMethod$object *);
};

// Vtable
struct _jc_scm_scmaddMethod$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmaddMethod$vmethods	scm_scmaddMethod;
};

// Vtype
struct _jc_scm_scmaddMethod$vtype {
	_jc_type			type;
	_jc_scm_scmaddMethod$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmaddMethod$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmaddMethod$refs {
    _jc_scm_scmaddMethod$sub_refs	scm_scmaddMethod;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmaddMethod$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmaddMethod$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmaddMethod$sub_nonrefs	scm_scmaddMethod;
};

// Object instance structure
struct _jc_scm_scmaddMethod$object {
	_jc_scm_scmaddMethod$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmaddMethod$vtype	*vtype;
	_jc_scm_scmaddMethod$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmaddMethod$vtype _jc_scm_scmaddMethod$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmaddMethod, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmaddMethod$class_object;

#endif	/* _JC_scm_scmaddMethod_H_ */

==> jc-1.4.6.tar.gz: scm/scmaddMethod.h <==
// class scm.scmaddMethod

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 2456fb15458328b3 scm_scmaddMethod

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmaddMethod_H_
#define _JC_scm_scmaddMethod_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmaddMethod$sub_refs	_jc_scm_scmaddMethod$sub_refs;
typedef struct _jc_scm_scmaddMethod$sub_nonrefs	_jc_scm_scmaddMethod$sub_nonrefs;
typedef struct _jc_scm_scmaddMethod$refs	_jc_scm_scmaddMethod$refs;
typedef struct _jc_scm_scmaddMethod$nonrefs	_jc_scm_scmaddMethod$nonrefs;
typedef struct _jc_scm_scmaddMethod$object	_jc_scm_scmaddMethod$object;

typedef const struct _jc_scm_scmaddMethod$vmethods	_jc_scm_scmaddMethod$vmethods;
typedef const struct _jc_scm_scmaddMethod$vtable	_jc_scm_scmaddMethod$vtable;
typedef const struct _jc_scm_scmaddMethod$vtype	_jc_scm_scmaddMethod$vtype;

// Constructors
extern void _jc_scm_scmaddMethod$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmaddMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_scmaddMethod$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmaddMethod$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_scmaddMethod$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmaddMethod$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_scmaddMethod$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmaddMethod$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmaddMethod$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmaddMethod$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmaddMethod$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_scmaddMethod$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmaddMethod$vmethods	scm_scmaddMethod;
};

// Vtype
struct _jc_scm_scmaddMethod$vtype {
	_jc_type			type;
	_jc_scm_scmaddMethod$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmaddMethod$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmaddMethod$refs {
    _jc_scm_scmaddMethod$sub_refs	scm_scmaddMethod;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmaddMethod$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmaddMethod$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmaddMethod$sub_nonrefs	scm_scmaddMethod;
};

// Object instance structure
struct _jc_scm_scmaddMethod$object {
	_jc_scm_scmaddMethod$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmaddMethod$vtype	*vtype;
	_jc_scm_scmaddMethod$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmaddMethod$vtype _jc_scm_scmaddMethod$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmaddMethod, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmaddMethod$class_object;

#endif	/* _JC_scm_scmaddMethod_H_ */
